Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6)

Unified Diff: include/codec/SkCodec.h

Issue 1006583005: SkCodec: add wbmp class (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: 2015-03-27 (Friday) 10:53:14 EDT Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « gyp/tests.gypi ('k') | resources/color_wheel.ico » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/codec/SkCodec.h
diff --git a/include/codec/SkCodec.h b/include/codec/SkCodec.h
index 5a69d1367d69444423c736cbbfbfc0e259c6180f..051564cf734ea0ee0129d5d20e0d73012905ad70 100644
--- a/include/codec/SkCodec.h
+++ b/include/codec/SkCodec.h
@@ -135,20 +135,26 @@ protected:
virtual bool onReallyHasAlpha() const { return false; }
+ enum RewindState {
+ kRewound_RewindState,
+ kNoRewindNecessary_RewindState,
+ kCouldNotRewind_RewindState
+ };
/**
* If the stream was previously read, attempt to rewind.
* @returns:
* true
* - if the stream needed to be rewound, and the rewind
* succeeded.
* - if the stream did not need to be rewound.
* false
* - if the stream needed to be rewound, and rewind failed.
* Subclasses MUST call this function before reading the stream (e.g. in
* onGetPixels). If it returns false, onGetPixels should return
* kCouldNotRewind.
*/
- bool SK_WARN_UNUSED_RESULT rewindIfNeeded();
+ RewindState SK_WARN_UNUSED_RESULT rewindIfNeeded();
/*
*
« no previous file with comments | « gyp/tests.gypi ('k') | resources/color_wheel.ico » ('j') | no next file with comments »
@@ -135,20 +135,26 @@ protected:
* If the stream was previously read, attempt to rewind.
* @returns:
- * true
- * - if the stream needed to be rewound, and the rewind
- * succeeded.
- * - if the stream did not need to be rewound.
- * false
- * - if the stream needed to be rewound, and rewind failed.
+ * kRewound if the stream needed to be rewound, and the
+ * rewind succeeded.
+ * kNoRewindNecessary if the stream did not need to be
+ * rewound.
+ * kCouldNotRewind if the stream needed to be rewound, and
+ * rewind failed.
+ *
* Subclasses MUST call this function before reading the stream (e.g. in
* onGetPixels). If it returns false, onGetPixels should return

Powered by Google App Engine
This is Rietveld 408576698